@@ -1,5 +1,5 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2015 Red Hat, Inc.
+# Copyright (C) 2020 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
@@ -19,7 +19,7 @@ from lib389 import Entry
 from lib389._mapped_object import DSLdapObjects, DSLdapObject
 from lib389.mappingTree import MappingTrees
 from lib389.exceptions import NoSuchEntryError, InvalidArgumentError
-from lib389.replica import Replicas
+from lib389.replica import Replicas, Changelog
 from lib389.cos import (CosTemplates, CosIndirectDefinitions,
                         CosPointerDefinitions, CosClassicDefinitions)
 
@@ -33,7 +33,7 @@ from lib389.encrypted_attributes import EncryptedAttr, EncryptedAttrs
 # This is for sample entry creation.
 from lib389.configurations import get_sample_entries
 
-from lib389.lint import DSBLE0001, DSBLE0002, DSBLE0003, DSVIRTLE0001
+from lib389.lint import DSBLE0001, DSBLE0002, DSBLE0003, DSVIRTLE0001, DSCLLE0001
 
 
 class BackendLegacy(object):
@@ -393,6 +393,10 @@ class BackendLegacy(object):
         replace = [(ldap.MOD_REPLACE, 'nsslapd-require-index', 'on')]
         self.modify_s(dn, replace)
 
+    @classmethod
+    def lint_uid(cls):
+        return 'backends'
+
 
 class Backend(DSLdapObject):
     """Backend DSLdapObject with:
@@ -413,19 +417,22 @@ class Backend(DSLdapObject):
         self._must_attributes = ['nsslapd-suffix', 'cn']
         self._create_objectclasses = ['top', 'extensibleObject', BACKEND_OBJECTCLASS_VALUE]
         self._protected = False
-        self._lint_functions = [self._lint_mappingtree, self._lint_search, self._lint_virt_attrs]
         # Check if a mapping tree for this suffix exists.
         self._mts = MappingTrees(self._instance)
 
+    def lint_uid(self):
+        return self.get_attr_val_utf8_l('cn').lower()
+
     def _lint_virt_attrs(self):
         """Check if any virtual attribute are incorrectly indexed"""
+        bename = self.lint_uid()
         indexes = self.get_indexes()
         suffix = self.get_attr_val_utf8('nsslapd-suffix')
-
         # First check nsrole
         try:
             indexes.get('nsrole')
             report = copy.deepcopy(DSVIRTLE0001)
+            report['check'] = f'backends:{bename}:virt_attrs'
             report['detail'] = report['detail'].replace('ATTR', 'nsrole')
             report['fix'] = report['fix'].replace('ATTR', 'nsrole')
             report['fix'] = report['fix'].replace('SUFFIX', suffix)
@@ -449,6 +456,7 @@ class Backend(DSLdapObject):
                         indexes.get(attr)
                         # If we got here there is an index (bad)
                         report = copy.deepcopy(DSVIRTLE0001)
+                        report['check'] = f'backends:{bename}:virt_attrs'
                         report['detail'] = report['detail'].replace('ATTR', attr)
                         report['fix'] = report['fix'].replace('ATTR', attr)
                         report['fix'] = report['fix'].replace('SUFFIX', suffix)
@@ -465,16 +473,19 @@ class Backend(DSLdapObject):
         """Perform a search and make sure an entry is accessible
         """
         dn = self.get_attr_val_utf8('nsslapd-suffix')
+        bename = self.lint_uid()
         suffix = DSLdapObject(self._instance, dn=dn)
         try:
             suffix.get_attr_val('objectclass')
         except ldap.NO_SUCH_OBJECT:
             # backend root entry not created yet
             DSBLE0003['items'] = [dn, ]
+            DSBLE0003['check'] = f'backends:{bename}:search'
             yield DSBLE0003
         except ldap.LDAPError as e:
             # Some other error
             DSBLE0002['detail'] = DSBLE0002['detail'].replace('ERROR', str(e))
+            DSBLE0002['check'] = f'backends:{bename}:search'
             DSBLE0002['items'] = [dn, ]
             yield DSBLE0002
 
@@ -485,19 +496,39 @@ class Backend(DSLdapObject):
         * missing mapping tree entries for the backend
         * missing indices if we are local and have log access?
         """
-
         # Check for the missing mapping tree.
         suffix = self.get_attr_val_utf8('nsslapd-suffix')
-        bename = self.get_attr_val_utf8('cn')
+        bename = self.lint_uid()
         try:
             mt = self._mts.get(suffix)
             if mt.get_attr_val_utf8('nsslapd-backend') != bename and mt.get_attr_val_utf8('nsslapd-state') != 'backend':
                 raise ldap.NO_SUCH_OBJECT("We have a matching suffix, but not a backend or correct database name.")
         except ldap.NO_SUCH_OBJECT:
             result = DSBLE0001
+            result['check'] = f'backends:{bename}:mappingtree'
             result['items'] = [bename, ]
             yield result
-        return None
+
+    def _lint_cl_trimming(self):
+        """Check that cl trimming is at least defined to prevent unbounded growth"""
+        bename = self.lint_uid()
+        suffix = self.get_attr_val_utf8('nsslapd-suffix')
+        replicas = Replicas(self._instance)
+        try:
+            # Check if replication is enabled
+            replicas.get(suffix)
+            # Check the changelog
+            cl = Changelog(self._instance, suffix=suffix)
+            if cl.get_attr_val_utf8('nsslapd-changelogmaxentries') is None and \
+               cl.get_attr_val_utf8('nsslapd-changelogmaxage') is None:
+                report = copy.deepcopy(DSCLLE0001)
+                report['fix'] = report['fix'].replace('YOUR_INSTANCE', self._instance.serverid)
+                report['check'] = f'backends:{bename}::cl_trimming'
+                yield report
+        except:
+            # Suffix is not replicated
+            self._log.debug(f"_lint_cl_trimming - backend ({suffix}) is not replicated")
+            pass
 
     def create_sample_entries(self, version):
         """Creates sample entries under nsslapd-suffix value
@@ -554,7 +585,7 @@ class Backend(DSLdapObject):
 
         return (dn, valid_props)
 
-    def create(self, dn=None, properties=None, basedn=DN_LDBM):
+    def create(self, dn=None, properties=None, basedn=DN_LDBM, create_mapping_tree=True):
         """Add a new backend entry, create mapping tree,
          and, if requested, sample entries
 
@@ -564,6 +595,8 @@ class Backend(DSLdapObject):
         :type properties: dict
         :param basedn: Base DN of the new entry
         :type basedn: str
+        :param create_mapping_tree: If a related mapping tree node should be created
+        :type create_mapping_tree: bool
 
         :returns: DSLdapObject of the created entry
         """
@@ -588,16 +621,19 @@ class Backend(DSLdapObject):
         super(Backend, self).create(dn, properties, basedn)
 
         # We check if the mapping tree exists in create, so do this *after*
-        properties = {
-            'cn': self._nprops_stash['nsslapd-suffix'],
-            'nsslapd-state': 'backend',
-            'nsslapd-backend': self._nprops_stash['cn'],
-        }
-        if parent_suffix:
-            # This is a subsuffix, set the parent suffix
-            properties['nsslapd-parent-suffix'] = parent_suffix
-        self._mts.create(properties=properties)
-        if sample_entries is not False:
+        if create_mapping_tree is True:
+            properties = {
+                'cn': self._nprops_stash['nsslapd-suffix'],
+                'nsslapd-state': 'backend',
+                'nsslapd-backend': self._nprops_stash['cn'],
+            }
+            if parent_suffix:
+                # This is a subsuffix, set the parent suffix
+                properties['nsslapd-parent-suffix'] = parent_suffix
+            self._mts.create(properties=properties)
+
+        # We can't create the sample entries unless a mapping tree was installed.
+        if sample_entries is not False and create_mapping_tree is True:
             self.create_sample_entries(sample_entries)
         return self
 
@@ -750,7 +786,7 @@ class Backend(DSLdapObject):
                 enc_attr.delete()
                 break
 
-    def import_ldif(self, ldifs, chunk_size=None, encrypted=False, gen_uniq_id=False, only_core=False,
+    def import_ldif(self, ldifs, chunk_size=None, encrypted=False, gen_uniq_id=None, only_core=False,
                     include_suffixes=None, exclude_suffixes=None):
         """Do an import of the suffix"""
 
@@ -848,6 +884,10 @@ class Backends(DSLdapObjects):
         self._childobject = Backend
         self._basedn = DN_LDBM
 
+    @classmethod
+    def lint_uid(cls):
+        return 'backends'
+
     def import_ldif(self, be_name, ldifs, chunk_size=None, encrypted=False, gen_uniq_id=None, only_core=False,
                     include_suffixes=None, exclude_suffixes=None):
         """Do an import of the suffix"""
@@ -931,6 +971,14 @@ class Backends(DSLdapObjects):
         task = task.create(properties=task_properties)
         return task
 
+    def delete_all_dangerous(self):
+        """
+        Delete all backends. This deletes from longest to shortest suffix
+        to ensure correct delete ordering.
+        """
+        for be in sorted(self.list(), key=lambda be: len(be.get_suffix()), reverse=True):
+            be.delete()
+
 
 class DatabaseConfig(DSLdapObject):
     """Backend Database configuration
@@ -1026,6 +1074,10 @@ class DatabaseConfig(DSLdapObject):
                 vo = vo[0]
             self._instance.log.info(f'{k}: {vo}')
 
+    def get_db_lib(self):
+        """Return the backend library, bdb, lmdb, etc"""
+        return self._db_lib
+
     def set(self, value_pairs):
         for attr, val in value_pairs:
             attr = attr.lower()
