@@ -21,6 +21,7 @@ from lib389.replica import Replicas
 from lib389.utils import ensure_str, is_a_dn, is_dn_parent
 from lib389._constants import *
 from lib389.cli_base import (
+    _format_status,
     _generic_get,
     _generic_get_dn,
     _get_arg,
@@ -240,11 +241,15 @@ def backend_import(inst, basedn, log, args):
     task = mc.import_ldif(ldifs=args.ldifs, chunk_size=args.chunks_size, encrypted=args.encrypted,
                           gen_uniq_id=args.gen_uniq_id, only_core=args.only_core, include_suffixes=args.include_suffixes,
                           exclude_suffixes=args.exclude_suffixes)
-    task.wait()
+    task.wait(timeout=None)
     result = task.get_exit_code()
+    warning = task.get_task_warn()
 
     if task.is_complete() and result == 0:
-        log.info("The import task has finished successfully")
+        if warning is None or (warning == 0):
+            log.info("The import task has finished successfully")
+        else:
+            log.info("The import task has finished successfully, with warning code {}, check the logs for more detail".format(warning))
     else:
         raise ValueError("Import task failed\n-------------------------\n{}".format(ensure_str(task.get_task_log())))
 
@@ -268,7 +273,7 @@ def backend_export(inst, basedn, log, args):
                           encrypted=args.encrypted, min_base64=args.min_base64, no_dump_uniq_id=args.no_dump_uniq_id,
                           replication=args.replication, not_folded=args.not_folded, no_seq_num=args.no_seq_num,
                           include_suffixes=args.include_suffixes, exclude_suffixes=args.exclude_suffixes)
-    task.wait()
+    task.wait(timeout=None)
     result = task.get_exit_code()
 
     if task.is_complete() and result == 0:
@@ -343,24 +348,19 @@ def backend_get_subsuffixes(inst, basedn, log, args):
 def build_node(suffix, be_name, subsuf=False, link=False, replicated=False):
     """Build the UI node for a suffix
     """
-    icon = "glyphicon glyphicon-tree-conifer"
     suffix_type = "suffix"
     if subsuf:
-        icon = "glyphicon glyphicon-leaf"
         suffix_type = "subsuffix"
     if link:
-        icon = "glyphicon glyphicon-link"
         suffix_type = "dblink"
 
     return {
-        "text": suffix,
+        "name": suffix,
         "id": suffix,
-        "selectable": True,
-        "icon": icon,
         "type": suffix_type,
         "replicated": replicated,
         "be": be_name,
-        "nodes": []
+        "children": []
     }
 
 
@@ -388,14 +388,14 @@ def backend_build_tree(inst, be_insts, nodes):
                         # We have a subsuffix (maybe a db link?)
                         link = is_db_link(inst, sub_be)
                         replicated = is_db_replicated(inst, sub_suffix)
-                        node['nodes'].append(build_node(sub_suffix,
+                        node['children'].append(build_node(sub_suffix,
                                                         sub_be,
                                                         subsuf=True,
                                                         link=link,
                                                         replicated=replicated))
 
                 # Recurse over the new subsuffixes
-                backend_build_tree(inst, be_insts, node['nodes'])
+                backend_build_tree(inst, be_insts, node['children'])
                 break
 
 
@@ -406,8 +406,8 @@ def print_suffix_tree(nodes, level, log):
         for node in nodes:
             spaces = " " * level
             log.info('{}- {}'.format(spaces, node['id']))
-            if len(node['nodes']) > 0:
-                print_suffix_tree(node['nodes'], level + 2, log)
+            if len(node['children']) > 0:
+                print_suffix_tree(node['children'], level + 2, log)
 
 
 def backend_get_tree(inst, basedn, log, args):
@@ -507,18 +507,6 @@ def db_config_set(inst, basedn, log, args):
     log.info("Successfully updated database configuration")
 
 
-def _format_status(log, mtype, json=False):
-    if json:
-        log.info(mtype.get_status_json())
-    else:
-        status_dict = mtype.get_status()
-        log.info('dn: ' + mtype._dn)
-        for k, v in list(status_dict.items()):
-           # For each value in the multivalue attr
-            for vi in v:
-                log.info('{}: {}'.format(k, vi))
-
-
 def get_monitor(inst, basedn, log, args):
     if args.suffix is not None:
         # Get a suffix/backend monitor entry
