@@ -431,7 +431,6 @@ class ReferentialIntegrityPlugin(Plugin):
             'referint-logfile',
             'referint-membership-attr',
         ])
-        self._lint_functions = [self._lint_update_delay, self._lint_attr_indexes]
 
     def create(self, rdn=None, properties=None, basedn=None):
         """Create an instance of the plugin"""
@@ -443,12 +442,17 @@ class ReferentialIntegrityPlugin(Plugin):
             properties['referint-logfile'] = referint_log
         return super(ReferentialIntegrityPlugin, self).create(rdn, properties, basedn)
 
+    @classmethod
+    def lint_uid(cls):
+        return 'refint'
+
     def _lint_update_delay(self):
         if self.status():
             delay = self.get_attr_val_int("referint-update-delay")
             if delay is not None and delay != 0:
                 report = copy.deepcopy(DSRILE0001)
                 report['fix'] = report['fix'].replace('YOUR_INSTANCE', self._instance.serverid)
+                report['check'] = f'refint:update_delay'
                 yield report
 
     def _lint_attr_indexes(self):
@@ -485,6 +489,7 @@ class ReferentialIntegrityPlugin(Plugin):
                             report['fix'] = report['fix'].replace('YOUR_INSTANCE', self._instance.serverid)
                             report['items'].append(suffix)
                             report['items'].append(attr)
+                            report['check'] = f'refint:attr_indexes'
                             yield report
                     except:
                         # No index at all, bad
@@ -495,6 +500,7 @@ class ReferentialIntegrityPlugin(Plugin):
                         report['fix'] = report['fix'].replace('YOUR_INSTANCE', self._instance.serverid)
                         report['items'].append(suffix)
                         report['items'].append(attr)
+                        report['check'] = f'refint:attr_indexes'
                         yield report
 
     def get_update_delay(self):
@@ -1878,7 +1884,7 @@ class AccountPolicyEntry(DSLdapObject):
     """
 
     def __init__(self, instance, dn=None):
-        super(AccountPolicyConfig, self).__init__(instance, dn)
+        super(AccountPolicyEntry, self).__init__(instance, dn)
         self._rdn_attribute = 'cn'
         self._must_attributes = ['cn']
         self._create_objectclasses = ['top', 'accountpolicy']
@@ -2225,3 +2231,48 @@ class BitwisePlugin(Plugin):
 
     def __init__(self, instance, dn="cn=Bitwise Plugin,cn=plugins,cn=config"):
         super(BitwisePlugin, self).__init__(instance, dn)
+
+
+class EntryUUIDPlugin(Plugin):
+    """The EntryUUID plugin configuration
+
+    :param instance: An instance
+    :type instance: lib389.DirSrv
+    :param dn: Entry DN
+    :type dn: str
+    """
+
+    def __init__(self, instance, dn="cn=entryuuid,cn=plugins,cn=config"):
+        super(EntryUUIDPlugin, self).__init__(instance, dn)
+
+    def fixup(self, basedn, _filter=None):
+        """Create an entryuuid fixup task
+
+        :param basedn: Basedn to fix up
+        :type basedn: str
+        :param _filter: a filter for entries to fix up
+        :type _filter: str
+
+        :returns: an instance of Task(DSLdapObject)
+        """
+
+        task = tasks.EntryUUIDFixupTask(self._instance)
+        task_properties = {'basedn': basedn}
+        if _filter is not None:
+            task_properties['filter'] = _filter
+        task.create(properties=task_properties)
+
+        return task
+
+class ContentSyncPlugin(Plugin):
+    """A single instance of Content Sync (aka syncrepl) plugin entry
+
+    :param instance: An instance
+    :type instance: lib389.DirSrv
+    :param dn: Entry DN
+    :type dn: str
+    """
+
+    def __init__(self, instance, dn="cn=Content Synchronization,cn=plugins,cn=config"):
+        super(ContentSyncPlugin, self).__init__(instance, dn)
+
